@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
+from io import BytesIO
 
 from pytest import importorskip
 
 from translate.convert import po2sub, test_convert
-from translate.misc import wStringIO
 from translate.storage import po
 
 
@@ -11,31 +10,29 @@ from translate.storage import po
 importorskip("aeidon")
 
 
-class TestPO2Sub(object):
+class TestPO2Sub:
 
     def po2sub(self, posource):
-        """helper that converts po source to subtitle source without requiring
-        files"""
-        inputfile = wStringIO.StringIO(posource)
+        """helper that converts po source to subtitle source without requiring files"""
+        inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
         convertor = po2sub.po2sub()
-        outputsub = convertor.convertstore(inputpo)
+        outputsub = convertor.convert_store(inputpo)
         return outputsub.decode('utf-8')
 
     def merge2sub(self, subsource, posource):
-        """helper that merges po translations to subtitle source without
-        requiring files"""
-        inputfile = wStringIO.StringIO(posource)
+        """helper that merges po translations to subtitle source without requiring files"""
+        inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
-        templatefile = wStringIO.StringIO(subsource)
+        templatefile = BytesIO(subsource.encode())
         convertor = po2sub.po2sub(templatefile, inputpo)
-        outputsub = convertor.convertstore()
+        outputsub = convertor.convert_store()
         print(outputsub)
         return outputsub.decode('utf-8')
 
     def test_subrip(self):
         """test SubRip or .srt files."""
-        posource = u'''#: 00:00:20.000-->00:00:24.400
+        posource = '''#: 00:00:20.000-->00:00:24.400
 msgid "Altocumulus clouds occur between six thousand"
 msgstr "Blah blah blah blah"
 
@@ -66,6 +63,7 @@ Koei koei koei koei
 
 class TestPO2SubCommand(test_convert.TestConvertCommand, TestPO2Sub):
     """Tests running actual po2sub commands on files"""
+
     convertmodule = po2sub
     defaultoptions = {"progress": "none"}
 
