@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 # 2013 F Wolff
@@ -21,7 +20,7 @@
 """An API to provide spell checking for use in checks or elsewhere."""
 
 import logging
-import six
+from functools import lru_cache
 
 
 logger = logging.getLogger(__name__)
@@ -30,7 +29,7 @@ available = False
 
 try:
     # Enchant
-    from enchant import checker, Error as EnchantError
+    from enchant import Error as EnchantError, checker
     available = True
     checkers = {}
 
@@ -39,10 +38,10 @@ try:
             try:
                 checkers[lang] = checker.SpellChecker(lang)
                 # some versions only report an error when checking something
-                checkers[lang].check(u'bla')
+                checkers[lang].check('bla')
             except EnchantError as e:
                 # sometimes this is raised instead of DictNotFoundError
-                logger.error(str(e))
+                logger.error('Dictionary not found: %s', e)
                 checkers[lang] = None
 
         return checkers[lang]
@@ -51,17 +50,17 @@ try:
         spellchecker = _get_checker(lang)
         if not spellchecker:
             return
-        spellchecker.set_text(six.text_type(text))
+        spellchecker.set_text(str(text))
         for err in spellchecker:
             yield err.word, err.wordpos, err.suggest()
 
+    @lru_cache(maxsize=1024)
     def simple_check(text, lang):
         spellchecker = _get_checker(lang)
         if not spellchecker:
-            return
-        spellchecker.set_text(six.text_type(text))
-        for err in spellchecker:
-            yield err.word
+            return []
+        spellchecker.set_text(str(text))
+        return [err.word for err in spellchecker]
 
 
 except ImportError:
