@@ -13,8 +13,10 @@ def test_punctranslate():
 
 
 def test_country_code():
-    """Tests that we get the correct one even if a country code is attached to
-    a special code being a reserved word in Python (like 'or')."""
+    """
+    Tests that we get the correct one even if a country code is attached to
+    a special code being a reserved word in Python (like 'or').
+    """
     language = factory.getlanguage('or-IN')
     assert language.fullname == "Odia"
 
