@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -22,21 +21,22 @@
 .. seealso:: http://en.wikipedia.org/wiki/Urdu_language
 """
 
+
 from translate.lang import common
 
 
 class ur(common.Common):
     """This class represents Urdu."""
 
-    listseperator = u"، "
+    listseperator = "، "
 
     puncdict = {
-        u".": u"۔",
-        u",": u"،",
-        u";": u"؛",
-        u"?": u"؟",
+        ".": "۔",
+        ",": "،",
+        ";": "؛",
+        "?": "؟",
         #This causes problems with variables, so commented out for now:
-        #u"%": u"٪",
+        #"%": "٪",
     }
 
     ignoretests = {
