@@ -1,19 +1,18 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
 
 import sys
+from io import BytesIO
 
 from pytest import importorskip, mark, raises
 
+from translate.misc.multistring import multistring
+from translate.storage import test_po
+
+
 pytestmark = mark.skipif(
     not sys.platform.startswith('linux'),
     reason="cpo is only available on Linux"
 )
 
-from translate.misc import wStringIO
-from translate.misc.multistring import multistring
-from translate.storage import test_po
-
 
 cpo = importorskip("translate.storage.cpo")
 
@@ -39,11 +38,11 @@ class TestCPOUnit(test_po.TestPOUnit):
         assert unit.target.strings == ["Koei", "Koeie"]
         assert unit.target == "Koei"
 
-        unit.target = [u"Sk\u00ear", u"Sk\u00eare"]
+        unit.target = ["Sk\u00ear", "Sk\u00eare"]
         assert isinstance(unit.target, multistring)
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target == u"Sk\u00ear"
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target == "Sk\u00ear"
 
     def test_plural_reduction(self):
         """checks that reducing the number of plurals supplied works"""
@@ -123,8 +122,8 @@ class TestCPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 2
         print(pofile.units[0].msgidcomments)
         print(pofile.units[1].msgidcomments)
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == "_: source1\n"
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == "_: source1\n"
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
     def test_msgid_comment(self):
@@ -134,8 +133,8 @@ class TestCPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 2
         pofile.removeduplicates("msgid_comment")
         assert len(pofile.units) == 2
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == "_: source0\n"
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == "_: source1\n"
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == "_: source0\n"
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source1\n"
         # Now lets check for formating
         for i in (0, 1):
             expected = '''#: source%d\nmsgid ""\n"_: source%d\\n"\n"Same"\nmsgstr ""\n''' % (i, i)
@@ -150,19 +149,19 @@ class TestCPOFile(test_po.TestPOFile):
         pofile.removeduplicates("keep")
         assert len(pofile.units) == 2
         # check we don't add msgidcomments
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == ""
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == ""
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == ""
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == ""
 
     def test_output_str_unicode(self):
         """checks that we can serialize pofile, unit content is in unicode"""
-        posource = u'''#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n'''
-        pofile = self.StoreClass(wStringIO.StringIO(posource.encode("UTF-8")), encoding="UTF-8")
+        posource = '''#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n'''
+        pofile = self.StoreClass(BytesIO(posource.encode("UTF-8")), encoding="UTF-8")
         assert len(pofile.units) == 1
         print(bytes(pofile))
         thepo = pofile.units[0]
 #        assert bytes(pofile) == posource.encode("UTF-8")
         # extra test: what if we set the msgid to a unicode? this happens in prop2po etc
-        thepo.source = u"Norwegian Bokm\xe5l"
+        thepo.source = "Norwegian Bokm\xe5l"
 #        assert str(thepo) == posource.encode("UTF-8")
         # Now if we set the msgstr to Unicode
         # this is an escaped half character (1/2)
@@ -198,3 +197,7 @@ class TestCPOFile(test_po.TestPOFile):
         print("serialize", bytes(oldfile))
         assert len(oldfile.units) == 1
         assert "# old lonesome comment\nmsgid" in bytes(oldfile).decode('utf-8')
+
+    @mark.xfail(reason="removal not working in cPO")
+    def test_remove(self):
+        super().test_remove()
